@@ -6,7 +6,7 @@ from epaycosdk.resources import Subscriptions
 from epaycosdk.resources import Bank
 from epaycosdk.resources import Cash
 from epaycosdk.resources import Charge
-from epaycosdk.resources import Safetypay
+#from epaycosdk.resources import Safetypay
 
 class Epayco:
 
@@ -28,4 +28,4 @@ class Epayco:
         self.bank = Bank(self)
         self.cash = Cash(self)
         self.charge=Charge(self)
-        self.safetypay=Safetypay(self)
+        #self.safetypay=Safetypay(self)
